SmsSender class
A Flutter plugin for sending SMS messages.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkPhoneStatePermission(
) → Future< bool> - Checks if the app has permission to read phone state (required for dual SIM support).
-
checkSmsPermission(
) → Future< bool> - Checks if the app has permission to send SMS messages.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPhoneStatePermission(
) → Future< bool> - Requests READ_PHONE_STATE permission from the user (required for dual SIM support).
-
requestSmsPermission(
) → Future< bool> - Requests SMS permission from the user.
-
sendSms(
{required String phoneNumber, required String message, int simSlot = 0}) → Future< bool> - Sends an SMS message to the specified phone number.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited